# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.auth_email_get_signup_settings_response_warnings_inner import AuthEmailGetSignupSettingsResponseWarningsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModForumGetForumAccessInformationResponse(BaseModel):
    """
    ModForumGetForumAccessInformationResponse
    """ # noqa: E501
    canaddinstance: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:addinstance allowed.")
    canaddnews: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:addnews allowed.")
    canaddquestion: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:addquestion allowed.")
    canallowforcesubscribe: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:allowforcesubscribe allowed.")
    cancanmailnow: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:canmailnow allowed.")
    cancanoverridecutoff: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:canoverridecutoff allowed.")
    cancanoverridediscussionlock: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:canoverridediscussionlock allowed.")
    cancanposttomygroups: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:canposttomygroups allowed.")
    cancantogglefavourite: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:cantogglefavourite allowed.")
    cancreateattachment: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:createattachment allowed.")
    candeleteanypost: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:deleteanypost allowed.")
    candeleteownpost: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:deleteownpost allowed.")
    caneditanypost: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:editanypost allowed.")
    canexportdiscussion: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:exportdiscussion allowed.")
    canexportforum: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:exportforum allowed.")
    canexportownpost: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:exportownpost allowed.")
    canexportpost: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:exportpost allowed.")
    cangrade: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:grade allowed.")
    canmanagesubscriptions: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:managesubscriptions allowed.")
    canmovediscussions: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:movediscussions allowed.")
    canpindiscussions: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:pindiscussions allowed.")
    canpostprivatereply: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:postprivatereply allowed.")
    canpostwithoutthrottling: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:postwithoutthrottling allowed.")
    canrate: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:rate allowed.")
    canreadprivatereplies: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:readprivatereplies allowed.")
    canreplynews: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:replynews allowed.")
    canreplypost: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:replypost allowed.")
    cansplitdiscussions: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:splitdiscussions allowed.")
    canstartdiscussion: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:startdiscussion allowed.")
    canviewallratings: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:viewallratings allowed.")
    canviewanyrating: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:viewanyrating allowed.")
    canviewdiscussion: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:viewdiscussion allowed.")
    canviewhiddentimedposts: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:viewhiddentimedposts allowed.")
    canviewqandawithoutposting: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:viewqandawithoutposting allowed.")
    canviewrating: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:viewrating allowed.")
    canviewsubscribers: Optional[StrictBool] = Field(default=None, description="Whether the user has the capability mod/forum:viewsubscribers allowed.")
    warnings: Optional[List[AuthEmailGetSignupSettingsResponseWarningsInner]] = Field(default=None, description="list of warnings")
    __properties: ClassVar[List[str]] = ["canaddinstance", "canaddnews", "canaddquestion", "canallowforcesubscribe", "cancanmailnow", "cancanoverridecutoff", "cancanoverridediscussionlock", "cancanposttomygroups", "cancantogglefavourite", "cancreateattachment", "candeleteanypost", "candeleteownpost", "caneditanypost", "canexportdiscussion", "canexportforum", "canexportownpost", "canexportpost", "cangrade", "canmanagesubscriptions", "canmovediscussions", "canpindiscussions", "canpostprivatereply", "canpostwithoutthrottling", "canrate", "canreadprivatereplies", "canreplynews", "canreplypost", "cansplitdiscussions", "canstartdiscussion", "canviewallratings", "canviewanyrating", "canviewdiscussion", "canviewhiddentimedposts", "canviewqandawithoutposting", "canviewrating", "canviewsubscribers", "warnings"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModForumGetForumAccessInformationResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in warnings (list)
        _items = []
        if self.warnings:
            for _item_warnings in self.warnings:
                if _item_warnings:
                    _items.append(_item_warnings.to_dict())
            _dict['warnings'] = _items
        # set to None if canaddinstance (nullable) is None
        # and model_fields_set contains the field
        if self.canaddinstance is None and "canaddinstance" in self.model_fields_set:
            _dict['canaddinstance'] = None

        # set to None if canaddnews (nullable) is None
        # and model_fields_set contains the field
        if self.canaddnews is None and "canaddnews" in self.model_fields_set:
            _dict['canaddnews'] = None

        # set to None if canaddquestion (nullable) is None
        # and model_fields_set contains the field
        if self.canaddquestion is None and "canaddquestion" in self.model_fields_set:
            _dict['canaddquestion'] = None

        # set to None if canallowforcesubscribe (nullable) is None
        # and model_fields_set contains the field
        if self.canallowforcesubscribe is None and "canallowforcesubscribe" in self.model_fields_set:
            _dict['canallowforcesubscribe'] = None

        # set to None if cancanmailnow (nullable) is None
        # and model_fields_set contains the field
        if self.cancanmailnow is None and "cancanmailnow" in self.model_fields_set:
            _dict['cancanmailnow'] = None

        # set to None if cancanoverridecutoff (nullable) is None
        # and model_fields_set contains the field
        if self.cancanoverridecutoff is None and "cancanoverridecutoff" in self.model_fields_set:
            _dict['cancanoverridecutoff'] = None

        # set to None if cancanoverridediscussionlock (nullable) is None
        # and model_fields_set contains the field
        if self.cancanoverridediscussionlock is None and "cancanoverridediscussionlock" in self.model_fields_set:
            _dict['cancanoverridediscussionlock'] = None

        # set to None if cancanposttomygroups (nullable) is None
        # and model_fields_set contains the field
        if self.cancanposttomygroups is None and "cancanposttomygroups" in self.model_fields_set:
            _dict['cancanposttomygroups'] = None

        # set to None if cancantogglefavourite (nullable) is None
        # and model_fields_set contains the field
        if self.cancantogglefavourite is None and "cancantogglefavourite" in self.model_fields_set:
            _dict['cancantogglefavourite'] = None

        # set to None if cancreateattachment (nullable) is None
        # and model_fields_set contains the field
        if self.cancreateattachment is None and "cancreateattachment" in self.model_fields_set:
            _dict['cancreateattachment'] = None

        # set to None if candeleteanypost (nullable) is None
        # and model_fields_set contains the field
        if self.candeleteanypost is None and "candeleteanypost" in self.model_fields_set:
            _dict['candeleteanypost'] = None

        # set to None if candeleteownpost (nullable) is None
        # and model_fields_set contains the field
        if self.candeleteownpost is None and "candeleteownpost" in self.model_fields_set:
            _dict['candeleteownpost'] = None

        # set to None if caneditanypost (nullable) is None
        # and model_fields_set contains the field
        if self.caneditanypost is None and "caneditanypost" in self.model_fields_set:
            _dict['caneditanypost'] = None

        # set to None if canexportdiscussion (nullable) is None
        # and model_fields_set contains the field
        if self.canexportdiscussion is None and "canexportdiscussion" in self.model_fields_set:
            _dict['canexportdiscussion'] = None

        # set to None if canexportforum (nullable) is None
        # and model_fields_set contains the field
        if self.canexportforum is None and "canexportforum" in self.model_fields_set:
            _dict['canexportforum'] = None

        # set to None if canexportownpost (nullable) is None
        # and model_fields_set contains the field
        if self.canexportownpost is None and "canexportownpost" in self.model_fields_set:
            _dict['canexportownpost'] = None

        # set to None if canexportpost (nullable) is None
        # and model_fields_set contains the field
        if self.canexportpost is None and "canexportpost" in self.model_fields_set:
            _dict['canexportpost'] = None

        # set to None if cangrade (nullable) is None
        # and model_fields_set contains the field
        if self.cangrade is None and "cangrade" in self.model_fields_set:
            _dict['cangrade'] = None

        # set to None if canmanagesubscriptions (nullable) is None
        # and model_fields_set contains the field
        if self.canmanagesubscriptions is None and "canmanagesubscriptions" in self.model_fields_set:
            _dict['canmanagesubscriptions'] = None

        # set to None if canmovediscussions (nullable) is None
        # and model_fields_set contains the field
        if self.canmovediscussions is None and "canmovediscussions" in self.model_fields_set:
            _dict['canmovediscussions'] = None

        # set to None if canpindiscussions (nullable) is None
        # and model_fields_set contains the field
        if self.canpindiscussions is None and "canpindiscussions" in self.model_fields_set:
            _dict['canpindiscussions'] = None

        # set to None if canpostprivatereply (nullable) is None
        # and model_fields_set contains the field
        if self.canpostprivatereply is None and "canpostprivatereply" in self.model_fields_set:
            _dict['canpostprivatereply'] = None

        # set to None if canpostwithoutthrottling (nullable) is None
        # and model_fields_set contains the field
        if self.canpostwithoutthrottling is None and "canpostwithoutthrottling" in self.model_fields_set:
            _dict['canpostwithoutthrottling'] = None

        # set to None if canrate (nullable) is None
        # and model_fields_set contains the field
        if self.canrate is None and "canrate" in self.model_fields_set:
            _dict['canrate'] = None

        # set to None if canreadprivatereplies (nullable) is None
        # and model_fields_set contains the field
        if self.canreadprivatereplies is None and "canreadprivatereplies" in self.model_fields_set:
            _dict['canreadprivatereplies'] = None

        # set to None if canreplynews (nullable) is None
        # and model_fields_set contains the field
        if self.canreplynews is None and "canreplynews" in self.model_fields_set:
            _dict['canreplynews'] = None

        # set to None if canreplypost (nullable) is None
        # and model_fields_set contains the field
        if self.canreplypost is None and "canreplypost" in self.model_fields_set:
            _dict['canreplypost'] = None

        # set to None if cansplitdiscussions (nullable) is None
        # and model_fields_set contains the field
        if self.cansplitdiscussions is None and "cansplitdiscussions" in self.model_fields_set:
            _dict['cansplitdiscussions'] = None

        # set to None if canstartdiscussion (nullable) is None
        # and model_fields_set contains the field
        if self.canstartdiscussion is None and "canstartdiscussion" in self.model_fields_set:
            _dict['canstartdiscussion'] = None

        # set to None if canviewallratings (nullable) is None
        # and model_fields_set contains the field
        if self.canviewallratings is None and "canviewallratings" in self.model_fields_set:
            _dict['canviewallratings'] = None

        # set to None if canviewanyrating (nullable) is None
        # and model_fields_set contains the field
        if self.canviewanyrating is None and "canviewanyrating" in self.model_fields_set:
            _dict['canviewanyrating'] = None

        # set to None if canviewdiscussion (nullable) is None
        # and model_fields_set contains the field
        if self.canviewdiscussion is None and "canviewdiscussion" in self.model_fields_set:
            _dict['canviewdiscussion'] = None

        # set to None if canviewhiddentimedposts (nullable) is None
        # and model_fields_set contains the field
        if self.canviewhiddentimedposts is None and "canviewhiddentimedposts" in self.model_fields_set:
            _dict['canviewhiddentimedposts'] = None

        # set to None if canviewqandawithoutposting (nullable) is None
        # and model_fields_set contains the field
        if self.canviewqandawithoutposting is None and "canviewqandawithoutposting" in self.model_fields_set:
            _dict['canviewqandawithoutposting'] = None

        # set to None if canviewrating (nullable) is None
        # and model_fields_set contains the field
        if self.canviewrating is None and "canviewrating" in self.model_fields_set:
            _dict['canviewrating'] = None

        # set to None if canviewsubscribers (nullable) is None
        # and model_fields_set contains the field
        if self.canviewsubscribers is None and "canviewsubscribers" in self.model_fields_set:
            _dict['canviewsubscribers'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModForumGetForumAccessInformationResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModForumGetForumAccessInformationResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "canaddinstance": obj.get("canaddinstance"),
            "canaddnews": obj.get("canaddnews"),
            "canaddquestion": obj.get("canaddquestion"),
            "canallowforcesubscribe": obj.get("canallowforcesubscribe"),
            "cancanmailnow": obj.get("cancanmailnow"),
            "cancanoverridecutoff": obj.get("cancanoverridecutoff"),
            "cancanoverridediscussionlock": obj.get("cancanoverridediscussionlock"),
            "cancanposttomygroups": obj.get("cancanposttomygroups"),
            "cancantogglefavourite": obj.get("cancantogglefavourite"),
            "cancreateattachment": obj.get("cancreateattachment"),
            "candeleteanypost": obj.get("candeleteanypost"),
            "candeleteownpost": obj.get("candeleteownpost"),
            "caneditanypost": obj.get("caneditanypost"),
            "canexportdiscussion": obj.get("canexportdiscussion"),
            "canexportforum": obj.get("canexportforum"),
            "canexportownpost": obj.get("canexportownpost"),
            "canexportpost": obj.get("canexportpost"),
            "cangrade": obj.get("cangrade"),
            "canmanagesubscriptions": obj.get("canmanagesubscriptions"),
            "canmovediscussions": obj.get("canmovediscussions"),
            "canpindiscussions": obj.get("canpindiscussions"),
            "canpostprivatereply": obj.get("canpostprivatereply"),
            "canpostwithoutthrottling": obj.get("canpostwithoutthrottling"),
            "canrate": obj.get("canrate"),
            "canreadprivatereplies": obj.get("canreadprivatereplies"),
            "canreplynews": obj.get("canreplynews"),
            "canreplypost": obj.get("canreplypost"),
            "cansplitdiscussions": obj.get("cansplitdiscussions"),
            "canstartdiscussion": obj.get("canstartdiscussion"),
            "canviewallratings": obj.get("canviewallratings"),
            "canviewanyrating": obj.get("canviewanyrating"),
            "canviewdiscussion": obj.get("canviewdiscussion"),
            "canviewhiddentimedposts": obj.get("canviewhiddentimedposts"),
            "canviewqandawithoutposting": obj.get("canviewqandawithoutposting"),
            "canviewrating": obj.get("canviewrating"),
            "canviewsubscribers": obj.get("canviewsubscribers"),
            "warnings": [AuthEmailGetSignupSettingsResponseWarningsInner.from_dict(_item) for _item in obj["warnings"]] if obj.get("warnings") is not None else None
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_attachmentfiles_inner import CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModWorkshopGetAssessmentResponseAssessment(BaseModel):
    """
    ModWorkshopGetAssessmentResponseAssessment
    """ # noqa: E501
    feedbackattachmentfiles: List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner] = Field(description="feedbackattachmentfiles")
    feedbackauthor: Optional[StrictStr] = Field(description="The comment/feedback from the reviewer for the author.")
    feedbackauthorattachment: Optional[StrictInt] = Field(description="Are there some files attached to the feedbackauthor field?                     Sets to 1 by file_postupdate_standard_filemanager().")
    feedbackauthorformat: Optional[StrictInt] = Field(default=0, description="feedbackauthor format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    feedbackcontentfiles: List[CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner] = Field(description="feedbackcontentfiles")
    feedbackreviewer: Optional[StrictStr] = Field(default=None, description="The comment/feedback from the teacher for the reviewer.                     For example the reason why the grade for assessment was overridden")
    feedbackreviewerformat: Optional[StrictInt] = Field(default=0, description="feedbackreviewer format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    grade: Optional[Union[StrictFloat, StrictInt]] = Field(description="The aggregated grade for submission suggested by the reviewer.                     The grade 0..100 is computed from the values assigned to the assessment dimensions fields. If NULL then it has not been aggregated yet.")
    gradinggrade: Optional[Union[StrictFloat, StrictInt]] = Field(description="The computed grade 0..100 for this assessment. If NULL then it has not been computed yet.")
    gradinggradeover: Optional[Union[StrictFloat, StrictInt]] = Field(description="Grade for the assessment manually overridden by a teacher.                     Grade is always from interval 0..100. If NULL then the grade is not overriden.")
    gradinggradeoverby: Optional[StrictInt] = Field(description="The id of the user who has overridden the grade for submission.")
    id: StrictInt = Field(description="The primary key of the record.")
    reviewerid: StrictInt = Field(description="The id of the reviewer who makes this assessment")
    submissionid: StrictInt = Field(description="The id of the assessed submission")
    timecreated: Optional[StrictInt] = Field(description="If 0 then the assessment was allocated but the reviewer has not assessed yet.                     If greater than 0 then the timestamp of when the reviewer assessed for the first time")
    timemodified: Optional[StrictInt] = Field(description="If 0 then the assessment was allocated but the reviewer has not assessed yet.                     If greater than 0 then the timestamp of when the reviewer assessed for the last time")
    weight: StrictInt = Field(description="The weight of the assessment for the purposes of aggregation")
    __properties: ClassVar[List[str]] = ["feedbackattachmentfiles", "feedbackauthor", "feedbackauthorattachment", "feedbackauthorformat", "feedbackcontentfiles", "feedbackreviewer", "feedbackreviewerformat", "grade", "gradinggrade", "gradinggradeover", "gradinggradeoverby", "id", "reviewerid", "submissionid", "timecreated", "timemodified", "weight"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModWorkshopGetAssessmentResponseAssessment from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in feedbackattachmentfiles (list)
        _items = []
        if self.feedbackattachmentfiles:
            for _item_feedbackattachmentfiles in self.feedbackattachmentfiles:
                if _item_feedbackattachmentfiles:
                    _items.append(_item_feedbackattachmentfiles.to_dict())
            _dict['feedbackattachmentfiles'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in feedbackcontentfiles (list)
        _items = []
        if self.feedbackcontentfiles:
            for _item_feedbackcontentfiles in self.feedbackcontentfiles:
                if _item_feedbackcontentfiles:
                    _items.append(_item_feedbackcontentfiles.to_dict())
            _dict['feedbackcontentfiles'] = _items
        # set to None if feedbackauthor (nullable) is None
        # and model_fields_set contains the field
        if self.feedbackauthor is None and "feedbackauthor" in self.model_fields_set:
            _dict['feedbackauthor'] = None

        # set to None if feedbackauthorattachment (nullable) is None
        # and model_fields_set contains the field
        if self.feedbackauthorattachment is None and "feedbackauthorattachment" in self.model_fields_set:
            _dict['feedbackauthorattachment'] = None

        # set to None if feedbackauthorformat (nullable) is None
        # and model_fields_set contains the field
        if self.feedbackauthorformat is None and "feedbackauthorformat" in self.model_fields_set:
            _dict['feedbackauthorformat'] = None

        # set to None if feedbackreviewer (nullable) is None
        # and model_fields_set contains the field
        if self.feedbackreviewer is None and "feedbackreviewer" in self.model_fields_set:
            _dict['feedbackreviewer'] = None

        # set to None if feedbackreviewerformat (nullable) is None
        # and model_fields_set contains the field
        if self.feedbackreviewerformat is None and "feedbackreviewerformat" in self.model_fields_set:
            _dict['feedbackreviewerformat'] = None

        # set to None if grade (nullable) is None
        # and model_fields_set contains the field
        if self.grade is None and "grade" in self.model_fields_set:
            _dict['grade'] = None

        # set to None if gradinggrade (nullable) is None
        # and model_fields_set contains the field
        if self.gradinggrade is None and "gradinggrade" in self.model_fields_set:
            _dict['gradinggrade'] = None

        # set to None if gradinggradeover (nullable) is None
        # and model_fields_set contains the field
        if self.gradinggradeover is None and "gradinggradeover" in self.model_fields_set:
            _dict['gradinggradeover'] = None

        # set to None if gradinggradeoverby (nullable) is None
        # and model_fields_set contains the field
        if self.gradinggradeoverby is None and "gradinggradeoverby" in self.model_fields_set:
            _dict['gradinggradeoverby'] = None

        # set to None if timecreated (nullable) is None
        # and model_fields_set contains the field
        if self.timecreated is None and "timecreated" in self.model_fields_set:
            _dict['timecreated'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModWorkshopGetAssessmentResponseAssessment from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModWorkshopGetAssessmentResponseAssessment" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "feedbackattachmentfiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["feedbackattachmentfiles"]] if obj.get("feedbackattachmentfiles") is not None else None,
            "feedbackauthor": obj.get("feedbackauthor"),
            "feedbackauthorattachment": obj.get("feedbackauthorattachment") if obj.get("feedbackauthorattachment") is not None else 0,
            "feedbackauthorformat": obj.get("feedbackauthorformat") if obj.get("feedbackauthorformat") is not None else 0,
            "feedbackcontentfiles": [CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner.from_dict(_item) for _item in obj["feedbackcontentfiles"]] if obj.get("feedbackcontentfiles") is not None else None,
            "feedbackreviewer": obj.get("feedbackreviewer"),
            "feedbackreviewerformat": obj.get("feedbackreviewerformat") if obj.get("feedbackreviewerformat") is not None else 0,
            "grade": obj.get("grade"),
            "gradinggrade": obj.get("gradinggrade"),
            "gradinggradeover": obj.get("gradinggradeover"),
            "gradinggradeoverby": obj.get("gradinggradeoverby"),
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "reviewerid": obj.get("reviewerid") if obj.get("reviewerid") is not None else 0,
            "submissionid": obj.get("submissionid") if obj.get("submissionid") is not None else 0,
            "timecreated": obj.get("timecreated") if obj.get("timecreated") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "weight": obj.get("weight") if obj.get("weight") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.mod_assign_get_submission_status_response_lastattempt_submission import ModAssignGetSubmissionStatusResponseLastattemptSubmission
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModAssignGetSubmissionStatusResponseLastattempt(BaseModel):
    """
    Last attempt information.
    """ # noqa: E501
    blindmarking: Optional[StrictBool] = Field(description="Whether blind marking is enabled.")
    canedit: Optional[StrictBool] = Field(description="Whether the user can edit the current submission.")
    caneditowner: Optional[StrictBool] = Field(description="Whether the owner of the submission can edit it.")
    cansubmit: Optional[StrictBool] = Field(description="Whether the user can submit.")
    extensionduedate: Optional[StrictInt] = Field(description="Extension due date.")
    graded: Optional[StrictBool] = Field(description="Whether the submission is graded.")
    gradingstatus: Optional[StrictStr] = Field(description="Grading status.")
    locked: Optional[StrictBool] = Field(description="Whether new submissions are locked.")
    submission: Optional[ModAssignGetSubmissionStatusResponseLastattemptSubmission] = None
    submissiongroup: Optional[StrictInt] = Field(default=None, description="The submission group id (for group submissions only).")
    submissiongroupmemberswhoneedtosubmit: Optional[List[Optional[StrictInt]]] = Field(default=None, description="List of users who still need to submit (for group submissions only).")
    submissionsenabled: Optional[StrictBool] = Field(description="Whether submissions are enabled or not.")
    teamsubmission: Optional[ModAssignGetSubmissionStatusResponseLastattemptSubmission] = None
    timelimit: Optional[StrictInt] = Field(default=None, description="Time limit for submission.")
    usergroups: List[Optional[StrictInt]] = Field(description="User groups in the course.")
    __properties: ClassVar[List[str]] = ["blindmarking", "canedit", "caneditowner", "cansubmit", "extensionduedate", "graded", "gradingstatus", "locked", "submission", "submissiongroup", "submissiongroupmemberswhoneedtosubmit", "submissionsenabled", "teamsubmission", "timelimit", "usergroups"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModAssignGetSubmissionStatusResponseLastattempt from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of submission
        if self.submission:
            _dict['submission'] = self.submission.to_dict()
        # override the default output from pydantic by calling `to_dict()` of teamsubmission
        if self.teamsubmission:
            _dict['teamsubmission'] = self.teamsubmission.to_dict()
        # set to None if blindmarking (nullable) is None
        # and model_fields_set contains the field
        if self.blindmarking is None and "blindmarking" in self.model_fields_set:
            _dict['blindmarking'] = None

        # set to None if canedit (nullable) is None
        # and model_fields_set contains the field
        if self.canedit is None and "canedit" in self.model_fields_set:
            _dict['canedit'] = None

        # set to None if caneditowner (nullable) is None
        # and model_fields_set contains the field
        if self.caneditowner is None and "caneditowner" in self.model_fields_set:
            _dict['caneditowner'] = None

        # set to None if cansubmit (nullable) is None
        # and model_fields_set contains the field
        if self.cansubmit is None and "cansubmit" in self.model_fields_set:
            _dict['cansubmit'] = None

        # set to None if extensionduedate (nullable) is None
        # and model_fields_set contains the field
        if self.extensionduedate is None and "extensionduedate" in self.model_fields_set:
            _dict['extensionduedate'] = None

        # set to None if graded (nullable) is None
        # and model_fields_set contains the field
        if self.graded is None and "graded" in self.model_fields_set:
            _dict['graded'] = None

        # set to None if gradingstatus (nullable) is None
        # and model_fields_set contains the field
        if self.gradingstatus is None and "gradingstatus" in self.model_fields_set:
            _dict['gradingstatus'] = None

        # set to None if locked (nullable) is None
        # and model_fields_set contains the field
        if self.locked is None and "locked" in self.model_fields_set:
            _dict['locked'] = None

        # set to None if submissiongroup (nullable) is None
        # and model_fields_set contains the field
        if self.submissiongroup is None and "submissiongroup" in self.model_fields_set:
            _dict['submissiongroup'] = None

        # set to None if submissionsenabled (nullable) is None
        # and model_fields_set contains the field
        if self.submissionsenabled is None and "submissionsenabled" in self.model_fields_set:
            _dict['submissionsenabled'] = None

        # set to None if timelimit (nullable) is None
        # and model_fields_set contains the field
        if self.timelimit is None and "timelimit" in self.model_fields_set:
            _dict['timelimit'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModAssignGetSubmissionStatusResponseLastattempt from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModAssignGetSubmissionStatusResponseLastattempt" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "blindmarking": obj.get("blindmarking"),
            "canedit": obj.get("canedit"),
            "caneditowner": obj.get("caneditowner"),
            "cansubmit": obj.get("cansubmit"),
            "extensionduedate": obj.get("extensionduedate"),
            "graded": obj.get("graded"),
            "gradingstatus": obj.get("gradingstatus"),
            "locked": obj.get("locked"),
            "submission": ModAssignGetSubmissionStatusResponseLastattemptSubmission.from_dict(obj["submission"]) if obj.get("submission") is not None else None,
            "submissiongroup": obj.get("submissiongroup"),
            "submissiongroupmemberswhoneedtosubmit": obj.get("submissiongroupmemberswhoneedtosubmit"),
            "submissionsenabled": obj.get("submissionsenabled"),
            "teamsubmission": ModAssignGetSubmissionStatusResponseLastattemptSubmission.from_dict(obj["teamsubmission"]) if obj.get("teamsubmission") is not None else None,
            "timelimit": obj.get("timelimit"),
            "usergroups": obj.get("usergroups")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_competency_create_plan_response_reviewer import CoreCompetencyCreatePlanResponseReviewer
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummaryEvidenceInner(BaseModel):
    """
    ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummaryEvidenceInner
    """ # noqa: E501
    action: StrictInt = Field(description="action")
    actionuser: Optional[CoreCompetencyCreatePlanResponseReviewer] = None
    actionuserid: Optional[StrictInt] = Field(description="actionuserid")
    candelete: StrictBool = Field(description="candelete")
    contextid: StrictInt = Field(description="contextid")
    desca: Optional[StrictStr] = Field(description="desca")
    desccomponent: StrictStr = Field(description="desccomponent")
    descidentifier: StrictStr = Field(description="descidentifier")
    description: StrictStr = Field(description="description")
    grade: Optional[StrictInt] = Field(description="grade")
    gradename: StrictStr = Field(description="gradename")
    id: StrictInt = Field(description="id")
    note: Optional[StrictStr] = Field(description="note")
    timecreated: StrictInt = Field(description="timecreated")
    timemodified: StrictInt = Field(description="timemodified")
    url: Optional[StrictStr] = Field(description="url")
    usercompetencyid: StrictInt = Field(description="usercompetencyid")
    userdate: StrictStr = Field(description="userdate")
    usermodified: StrictInt = Field(description="usermodified")
    __properties: ClassVar[List[str]] = ["action", "actionuser", "actionuserid", "candelete", "contextid", "desca", "desccomponent", "descidentifier", "description", "grade", "gradename", "id", "note", "timecreated", "timemodified", "url", "usercompetencyid", "userdate", "usermodified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummaryEvidenceInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of actionuser
        if self.actionuser:
            _dict['actionuser'] = self.actionuser.to_dict()
        # set to None if actionuserid (nullable) is None
        # and model_fields_set contains the field
        if self.actionuserid is None and "actionuserid" in self.model_fields_set:
            _dict['actionuserid'] = None

        # set to None if desca (nullable) is None
        # and model_fields_set contains the field
        if self.desca is None and "desca" in self.model_fields_set:
            _dict['desca'] = None

        # set to None if grade (nullable) is None
        # and model_fields_set contains the field
        if self.grade is None and "grade" in self.model_fields_set:
            _dict['grade'] = None

        # set to None if note (nullable) is None
        # and model_fields_set contains the field
        if self.note is None and "note" in self.model_fields_set:
            _dict['note'] = None

        # set to None if url (nullable) is None
        # and model_fields_set contains the field
        if self.url is None and "url" in self.model_fields_set:
            _dict['url'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummaryEvidenceInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummaryEvidenceInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "action": obj.get("action") if obj.get("action") is not None else 0,
            "actionuser": CoreCompetencyCreatePlanResponseReviewer.from_dict(obj["actionuser"]) if obj.get("actionuser") is not None else None,
            "actionuserid": obj.get("actionuserid"),
            "candelete": obj.get("candelete") if obj.get("candelete") is not None else False,
            "contextid": obj.get("contextid") if obj.get("contextid") is not None else 0,
            "desca": obj.get("desca"),
            "desccomponent": obj.get("desccomponent") if obj.get("desccomponent") is not None else '',
            "descidentifier": obj.get("descidentifier") if obj.get("descidentifier") is not None else '',
            "description": obj.get("description") if obj.get("description") is not None else '',
            "grade": obj.get("grade"),
            "gradename": obj.get("gradename") if obj.get("gradename") is not None else '',
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "note": obj.get("note"),
            "timecreated": obj.get("timecreated") if obj.get("timecreated") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "url": obj.get("url"),
            "usercompetencyid": obj.get("usercompetencyid") if obj.get("usercompetencyid") is not None else 0,
            "userdate": obj.get("userdate") if obj.get("userdate") is not None else '',
            "usermodified": obj.get("usermodified") if obj.get("usermodified") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_guide import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuide
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_rubric import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubric
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInner(BaseModel):
    """
    CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInner
    """ # noqa: E501
    copiedfromid: Optional[StrictInt] = Field(default=None, description="copied from id")
    description: Optional[StrictStr] = Field(default=None, description="description")
    descriptionformat: Optional[StrictInt] = Field(default=None, description="description format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    guide: Optional[CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuide] = None
    id: Optional[StrictInt] = Field(default=None, description="definition id")
    method: Optional[StrictStr] = Field(description="method")
    name: Optional[StrictStr] = Field(description="name")
    rubric: Optional[CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubric] = None
    status: Optional[StrictInt] = Field(description="status")
    timecopied: Optional[StrictInt] = Field(default=None, description="time copied")
    timecreated: Optional[StrictInt] = Field(description="creation time")
    timemodified: Optional[StrictInt] = Field(description="last modified time")
    usercreated: Optional[StrictInt] = Field(description="user who created definition")
    usermodified: Optional[StrictInt] = Field(description="user who modified definition")
    __properties: ClassVar[List[str]] = ["copiedfromid", "description", "descriptionformat", "guide", "id", "method", "name", "rubric", "status", "timecopied", "timecreated", "timemodified", "usercreated", "usermodified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of guide
        if self.guide:
            _dict['guide'] = self.guide.to_dict()
        # override the default output from pydantic by calling `to_dict()` of rubric
        if self.rubric:
            _dict['rubric'] = self.rubric.to_dict()
        # set to None if copiedfromid (nullable) is None
        # and model_fields_set contains the field
        if self.copiedfromid is None and "copiedfromid" in self.model_fields_set:
            _dict['copiedfromid'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if descriptionformat (nullable) is None
        # and model_fields_set contains the field
        if self.descriptionformat is None and "descriptionformat" in self.model_fields_set:
            _dict['descriptionformat'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if method (nullable) is None
        # and model_fields_set contains the field
        if self.method is None and "method" in self.model_fields_set:
            _dict['method'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if timecopied (nullable) is None
        # and model_fields_set contains the field
        if self.timecopied is None and "timecopied" in self.model_fields_set:
            _dict['timecopied'] = None

        # set to None if timecreated (nullable) is None
        # and model_fields_set contains the field
        if self.timecreated is None and "timecreated" in self.model_fields_set:
            _dict['timecreated'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if usercreated (nullable) is None
        # and model_fields_set contains the field
        if self.usercreated is None and "usercreated" in self.model_fields_set:
            _dict['usercreated'] = None

        # set to None if usermodified (nullable) is None
        # and model_fields_set contains the field
        if self.usermodified is None and "usermodified" in self.model_fields_set:
            _dict['usermodified'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "copiedfromid": obj.get("copiedfromid"),
            "description": obj.get("description"),
            "descriptionformat": obj.get("descriptionformat"),
            "guide": CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuide.from_dict(obj["guide"]) if obj.get("guide") is not None else None,
            "id": obj.get("id"),
            "method": obj.get("method"),
            "name": obj.get("name"),
            "rubric": CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubric.from_dict(obj["rubric"]) if obj.get("rubric") is not None else None,
            "status": obj.get("status"),
            "timecopied": obj.get("timecopied"),
            "timecreated": obj.get("timecreated"),
            "timemodified": obj.get("timemodified"),
            "usercreated": obj.get("usercreated"),
            "usermodified": obj.get("usermodified")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_calendar_get_calendar_day_view_response_date import CoreCalendarGetCalendarDayViewResponseDate
from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response_daynames_inner import CoreCalendarGetCalendarMonthlyViewResponseDaynamesInner
from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response_weeks_inner import CoreCalendarGetCalendarMonthlyViewResponseWeeksInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreCalendarGetCalendarMonthlyViewResponse(BaseModel):
    """
    CoreCalendarGetCalendarMonthlyViewResponse
    """ # noqa: E501
    calendarinstanceid: StrictInt = Field(description="calendarinstanceid")
    categoryid: Optional[StrictInt] = Field(default=0, description="categoryid")
    courseid: StrictInt = Field(description="courseid")
    var_date: CoreCalendarGetCalendarDayViewResponseDate = Field(alias="date")
    daynames: List[CoreCalendarGetCalendarMonthlyViewResponseDaynamesInner] = Field(description="daynames")
    defaulteventcontext: StrictInt = Field(description="defaulteventcontext")
    filter_selector: Optional[StrictStr] = Field(default='', description="filter_selector")
    includenavigation: StrictBool = Field(description="includenavigation")
    initialeventsloaded: StrictBool = Field(description="initialeventsloaded")
    larrow: StrictStr = Field(description="larrow")
    nextperiod: CoreCalendarGetCalendarDayViewResponseDate
    nextperiodlink: StrictStr = Field(description="nextperiodlink")
    nextperiodname: StrictStr = Field(description="nextperiodname")
    periodname: StrictStr = Field(description="periodname")
    previousperiod: CoreCalendarGetCalendarDayViewResponseDate
    previousperiodlink: StrictStr = Field(description="previousperiodlink")
    previousperiodname: StrictStr = Field(description="previousperiodname")
    rarrow: StrictStr = Field(description="rarrow")
    showviewselector: StrictBool = Field(description="showviewselector")
    url: StrictStr = Field(description="url")
    view: StrictStr = Field(description="view")
    viewinginblock: StrictBool = Field(description="viewinginblock")
    viewingmonth: StrictBool = Field(description="viewingmonth")
    weeks: List[CoreCalendarGetCalendarMonthlyViewResponseWeeksInner] = Field(description="weeks")
    __properties: ClassVar[List[str]] = ["calendarinstanceid", "categoryid", "courseid", "date", "daynames", "defaulteventcontext", "filter_selector", "includenavigation", "initialeventsloaded", "larrow", "nextperiod", "nextperiodlink", "nextperiodname", "periodname", "previousperiod", "previousperiodlink", "previousperiodname", "rarrow", "showviewselector", "url", "view", "viewinginblock", "viewingmonth", "weeks"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCalendarGetCalendarMonthlyViewResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of var_date
        if self.var_date:
            _dict['date'] = self.var_date.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in daynames (list)
        _items = []
        if self.daynames:
            for _item_daynames in self.daynames:
                if _item_daynames:
                    _items.append(_item_daynames.to_dict())
            _dict['daynames'] = _items
        # override the default output from pydantic by calling `to_dict()` of nextperiod
        if self.nextperiod:
            _dict['nextperiod'] = self.nextperiod.to_dict()
        # override the default output from pydantic by calling `to_dict()` of previousperiod
        if self.previousperiod:
            _dict['previousperiod'] = self.previousperiod.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in weeks (list)
        _items = []
        if self.weeks:
            for _item_weeks in self.weeks:
                if _item_weeks:
                    _items.append(_item_weeks.to_dict())
            _dict['weeks'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCalendarGetCalendarMonthlyViewResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCalendarGetCalendarMonthlyViewResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "calendarinstanceid": obj.get("calendarinstanceid") if obj.get("calendarinstanceid") is not None else 0,
            "categoryid": obj.get("categoryid") if obj.get("categoryid") is not None else 0,
            "courseid": obj.get("courseid") if obj.get("courseid") is not None else 0,
            "date": CoreCalendarGetCalendarDayViewResponseDate.from_dict(obj["date"]) if obj.get("date") is not None else None,
            "daynames": [CoreCalendarGetCalendarMonthlyViewResponseDaynamesInner.from_dict(_item) for _item in obj["daynames"]] if obj.get("daynames") is not None else None,
            "defaulteventcontext": obj.get("defaulteventcontext") if obj.get("defaulteventcontext") is not None else 0,
            "filter_selector": obj.get("filter_selector") if obj.get("filter_selector") is not None else '',
            "includenavigation": obj.get("includenavigation") if obj.get("includenavigation") is not None else True,
            "initialeventsloaded": obj.get("initialeventsloaded") if obj.get("initialeventsloaded") is not None else True,
            "larrow": obj.get("larrow") if obj.get("larrow") is not None else '',
            "nextperiod": CoreCalendarGetCalendarDayViewResponseDate.from_dict(obj["nextperiod"]) if obj.get("nextperiod") is not None else None,
            "nextperiodlink": obj.get("nextperiodlink") if obj.get("nextperiodlink") is not None else '',
            "nextperiodname": obj.get("nextperiodname") if obj.get("nextperiodname") is not None else '',
            "periodname": obj.get("periodname") if obj.get("periodname") is not None else '',
            "previousperiod": CoreCalendarGetCalendarDayViewResponseDate.from_dict(obj["previousperiod"]) if obj.get("previousperiod") is not None else None,
            "previousperiodlink": obj.get("previousperiodlink") if obj.get("previousperiodlink") is not None else '',
            "previousperiodname": obj.get("previousperiodname") if obj.get("previousperiodname") is not None else '',
            "rarrow": obj.get("rarrow") if obj.get("rarrow") is not None else '',
            "showviewselector": obj.get("showviewselector") if obj.get("showviewselector") is not None else True,
            "url": obj.get("url") if obj.get("url") is not None else '',
            "view": obj.get("view") if obj.get("view") is not None else '',
            "viewinginblock": obj.get("viewinginblock") if obj.get("viewinginblock") is not None else False,
            "viewingmonth": obj.get("viewingmonth") if obj.get("viewingmonth") is not None else True,
            "weeks": [CoreCalendarGetCalendarMonthlyViewResponseWeeksInner.from_dict(_item) for _item in obj["weeks"]] if obj.get("weeks") is not None else None
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents_files_inner import CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModForumGetForumDiscussionsResponseDiscussionsInner(BaseModel):
    """
    post
    """ # noqa: E501
    attachment: Optional[StrictStr] = Field(description="Has attachments?")
    attachments: Optional[List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner]] = Field(default=None, description="attachments")
    canfavourite: Optional[StrictBool] = Field(description="Can the user star the discussion")
    canlock: Optional[StrictBool] = Field(description="Can the user lock the discussion")
    canreply: Optional[StrictBool] = Field(description="Can the user reply to the discussion")
    created: Optional[StrictInt] = Field(description="Creation time")
    discussion: Optional[StrictInt] = Field(description="Discussion id")
    groupid: Optional[StrictInt] = Field(description="Group id")
    id: Optional[StrictInt] = Field(description="Post id")
    locked: Optional[StrictBool] = Field(description="Is the discussion locked")
    mailed: Optional[StrictInt] = Field(description="Mailed?")
    mailnow: Optional[StrictInt] = Field(description="Mail now?")
    message: Optional[StrictStr] = Field(description="The post message")
    messageformat: Optional[StrictInt] = Field(description="message format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    messageinlinefiles: Optional[List[CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner]] = Field(default=None, description="post message inline files")
    messagetrust: Optional[StrictInt] = Field(description="Can we trust?")
    modified: Optional[StrictInt] = Field(description="Time modified")
    name: Optional[StrictStr] = Field(description="Discussion name")
    numreplies: Optional[StrictInt] = Field(description="The number of replies in the discussion")
    numunread: Optional[StrictInt] = Field(description="The number of unread discussions.")
    parent: Optional[StrictInt] = Field(description="Parent id")
    pinned: Optional[StrictBool] = Field(description="Is the discussion pinned")
    starred: Optional[StrictBool] = Field(description="Is the discussion starred")
    subject: Optional[StrictStr] = Field(description="The post subject")
    timeend: Optional[StrictInt] = Field(description="Time discussion ends")
    timemodified: Optional[StrictInt] = Field(description="Time modified")
    timestart: Optional[StrictInt] = Field(description="Time discussion can start")
    totalscore: Optional[StrictInt] = Field(description="The post message total score")
    userfullname: Optional[StrictStr] = Field(description="Post author full name")
    userid: Optional[StrictInt] = Field(description="User who started the discussion id")
    usermodified: Optional[StrictInt] = Field(description="The id of the user who last modified")
    usermodifiedfullname: Optional[StrictStr] = Field(description="Post modifier full name")
    usermodifiedpictureurl: Optional[StrictStr] = Field(description="Post modifier picture.")
    userpictureurl: Optional[StrictStr] = Field(description="Post author picture.")
    __properties: ClassVar[List[str]] = ["attachment", "attachments", "canfavourite", "canlock", "canreply", "created", "discussion", "groupid", "id", "locked", "mailed", "mailnow", "message", "messageformat", "messageinlinefiles", "messagetrust", "modified", "name", "numreplies", "numunread", "parent", "pinned", "starred", "subject", "timeend", "timemodified", "timestart", "totalscore", "userfullname", "userid", "usermodified", "usermodifiedfullname", "usermodifiedpictureurl", "userpictureurl"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModForumGetForumDiscussionsResponseDiscussionsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in attachments (list)
        _items = []
        if self.attachments:
            for _item_attachments in self.attachments:
                if _item_attachments:
                    _items.append(_item_attachments.to_dict())
            _dict['attachments'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in messageinlinefiles (list)
        _items = []
        if self.messageinlinefiles:
            for _item_messageinlinefiles in self.messageinlinefiles:
                if _item_messageinlinefiles:
                    _items.append(_item_messageinlinefiles.to_dict())
            _dict['messageinlinefiles'] = _items
        # set to None if attachment (nullable) is None
        # and model_fields_set contains the field
        if self.attachment is None and "attachment" in self.model_fields_set:
            _dict['attachment'] = None

        # set to None if canfavourite (nullable) is None
        # and model_fields_set contains the field
        if self.canfavourite is None and "canfavourite" in self.model_fields_set:
            _dict['canfavourite'] = None

        # set to None if canlock (nullable) is None
        # and model_fields_set contains the field
        if self.canlock is None and "canlock" in self.model_fields_set:
            _dict['canlock'] = None

        # set to None if canreply (nullable) is None
        # and model_fields_set contains the field
        if self.canreply is None and "canreply" in self.model_fields_set:
            _dict['canreply'] = None

        # set to None if created (nullable) is None
        # and model_fields_set contains the field
        if self.created is None and "created" in self.model_fields_set:
            _dict['created'] = None

        # set to None if discussion (nullable) is None
        # and model_fields_set contains the field
        if self.discussion is None and "discussion" in self.model_fields_set:
            _dict['discussion'] = None

        # set to None if groupid (nullable) is None
        # and model_fields_set contains the field
        if self.groupid is None and "groupid" in self.model_fields_set:
            _dict['groupid'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if locked (nullable) is None
        # and model_fields_set contains the field
        if self.locked is None and "locked" in self.model_fields_set:
            _dict['locked'] = None

        # set to None if mailed (nullable) is None
        # and model_fields_set contains the field
        if self.mailed is None and "mailed" in self.model_fields_set:
            _dict['mailed'] = None

        # set to None if mailnow (nullable) is None
        # and model_fields_set contains the field
        if self.mailnow is None and "mailnow" in self.model_fields_set:
            _dict['mailnow'] = None

        # set to None if message (nullable) is None
        # and model_fields_set contains the field
        if self.message is None and "message" in self.model_fields_set:
            _dict['message'] = None

        # set to None if messageformat (nullable) is None
        # and model_fields_set contains the field
        if self.messageformat is None and "messageformat" in self.model_fields_set:
            _dict['messageformat'] = None

        # set to None if messagetrust (nullable) is None
        # and model_fields_set contains the field
        if self.messagetrust is None and "messagetrust" in self.model_fields_set:
            _dict['messagetrust'] = None

        # set to None if modified (nullable) is None
        # and model_fields_set contains the field
        if self.modified is None and "modified" in self.model_fields_set:
            _dict['modified'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if numreplies (nullable) is None
        # and model_fields_set contains the field
        if self.numreplies is None and "numreplies" in self.model_fields_set:
            _dict['numreplies'] = None

        # set to None if numunread (nullable) is None
        # and model_fields_set contains the field
        if self.numunread is None and "numunread" in self.model_fields_set:
            _dict['numunread'] = None

        # set to None if parent (nullable) is None
        # and model_fields_set contains the field
        if self.parent is None and "parent" in self.model_fields_set:
            _dict['parent'] = None

        # set to None if pinned (nullable) is None
        # and model_fields_set contains the field
        if self.pinned is None and "pinned" in self.model_fields_set:
            _dict['pinned'] = None

        # set to None if starred (nullable) is None
        # and model_fields_set contains the field
        if self.starred is None and "starred" in self.model_fields_set:
            _dict['starred'] = None

        # set to None if subject (nullable) is None
        # and model_fields_set contains the field
        if self.subject is None and "subject" in self.model_fields_set:
            _dict['subject'] = None

        # set to None if timeend (nullable) is None
        # and model_fields_set contains the field
        if self.timeend is None and "timeend" in self.model_fields_set:
            _dict['timeend'] = None

        # set to None if timemodified (nullable) is None
        # and model_fields_set contains the field
        if self.timemodified is None and "timemodified" in self.model_fields_set:
            _dict['timemodified'] = None

        # set to None if timestart (nullable) is None
        # and model_fields_set contains the field
        if self.timestart is None and "timestart" in self.model_fields_set:
            _dict['timestart'] = None

        # set to None if totalscore (nullable) is None
        # and model_fields_set contains the field
        if self.totalscore is None and "totalscore" in self.model_fields_set:
            _dict['totalscore'] = None

        # set to None if userfullname (nullable) is None
        # and model_fields_set contains the field
        if self.userfullname is None and "userfullname" in self.model_fields_set:
            _dict['userfullname'] = None

        # set to None if userid (nullable) is None
        # and model_fields_set contains the field
        if self.userid is None and "userid" in self.model_fields_set:
            _dict['userid'] = None

        # set to None if usermodified (nullable) is None
        # and model_fields_set contains the field
        if self.usermodified is None and "usermodified" in self.model_fields_set:
            _dict['usermodified'] = None

        # set to None if usermodifiedfullname (nullable) is None
        # and model_fields_set contains the field
        if self.usermodifiedfullname is None and "usermodifiedfullname" in self.model_fields_set:
            _dict['usermodifiedfullname'] = None

        # set to None if usermodifiedpictureurl (nullable) is None
        # and model_fields_set contains the field
        if self.usermodifiedpictureurl is None and "usermodifiedpictureurl" in self.model_fields_set:
            _dict['usermodifiedpictureurl'] = None

        # set to None if userpictureurl (nullable) is None
        # and model_fields_set contains the field
        if self.userpictureurl is None and "userpictureurl" in self.model_fields_set:
            _dict['userpictureurl'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModForumGetForumDiscussionsResponseDiscussionsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModForumGetForumDiscussionsResponseDiscussionsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "attachment": obj.get("attachment"),
            "attachments": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["attachments"]] if obj.get("attachments") is not None else None,
            "canfavourite": obj.get("canfavourite"),
            "canlock": obj.get("canlock"),
            "canreply": obj.get("canreply"),
            "created": obj.get("created"),
            "discussion": obj.get("discussion"),
            "groupid": obj.get("groupid"),
            "id": obj.get("id"),
            "locked": obj.get("locked"),
            "mailed": obj.get("mailed"),
            "mailnow": obj.get("mailnow"),
            "message": obj.get("message"),
            "messageformat": obj.get("messageformat"),
            "messageinlinefiles": [CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner.from_dict(_item) for _item in obj["messageinlinefiles"]] if obj.get("messageinlinefiles") is not None else None,
            "messagetrust": obj.get("messagetrust"),
            "modified": obj.get("modified"),
            "name": obj.get("name"),
            "numreplies": obj.get("numreplies"),
            "numunread": obj.get("numunread"),
            "parent": obj.get("parent"),
            "pinned": obj.get("pinned"),
            "starred": obj.get("starred"),
            "subject": obj.get("subject"),
            "timeend": obj.get("timeend"),
            "timemodified": obj.get("timemodified"),
            "timestart": obj.get("timestart"),
            "totalscore": obj.get("totalscore"),
            "userfullname": obj.get("userfullname"),
            "userid": obj.get("userid"),
            "usermodified": obj.get("usermodified"),
            "usermodifiedfullname": obj.get("usermodifiedfullname"),
            "usermodifiedpictureurl": obj.get("usermodifiedpictureurl"),
            "userpictureurl": obj.get("userpictureurl")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.core_competency_create_plan_response_reviewer import CoreCompetencyCreatePlanResponseReviewer
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ToolDataprivacyGetDataRequestResponseResult(BaseModel):
    """
    ToolDataprivacyGetDataRequestResponseResult
    """ # noqa: E501
    allowfiltering: Optional[StrictBool] = Field(default=False, description="allowfiltering")
    approvedeny: Optional[StrictBool] = Field(default=False, description="approvedeny")
    canmarkcomplete: Optional[StrictBool] = Field(default=False, description="canmarkcomplete")
    canreview: Optional[StrictBool] = Field(default=False, description="canreview")
    comments: StrictStr = Field(description="comments")
    commentsformat: StrictInt = Field(description="commentsformat")
    creationmethod: StrictInt = Field(description="creationmethod")
    downloadlink: Optional[StrictStr] = Field(default='', description="downloadlink")
    dpo: Optional[StrictInt] = Field(description="dpo")
    dpocomment: Optional[StrictStr] = Field(description="dpocomment")
    dpocommentformat: StrictInt = Field(description="dpocommentformat")
    dpouser: Optional[CoreCompetencyCreatePlanResponseReviewer] = None
    foruser: CoreCompetencyCreatePlanResponseReviewer
    id: StrictInt = Field(description="id")
    messagehtml: Optional[StrictStr] = Field(default='', description="messagehtml")
    requestedby: StrictInt = Field(description="requestedby")
    requestedbyuser: Optional[CoreCompetencyCreatePlanResponseReviewer] = None
    status: StrictInt = Field(description="status")
    statuslabel: StrictStr = Field(description="statuslabel")
    statuslabelclass: StrictStr = Field(description="statuslabelclass")
    systemapproved: StrictBool = Field(description="systemapproved")
    timecreated: StrictInt = Field(description="timecreated")
    timemodified: StrictInt = Field(description="timemodified")
    type: StrictInt = Field(description="type")
    typename: StrictStr = Field(description="typename")
    typenameshort: StrictStr = Field(description="typenameshort")
    userid: StrictInt = Field(description="userid")
    usermodified: StrictInt = Field(description="usermodified")
    __properties: ClassVar[List[str]] = ["allowfiltering", "approvedeny", "canmarkcomplete", "canreview", "comments", "commentsformat", "creationmethod", "downloadlink", "dpo", "dpocomment", "dpocommentformat", "dpouser", "foruser", "id", "messagehtml", "requestedby", "requestedbyuser", "status", "statuslabel", "statuslabelclass", "systemapproved", "timecreated", "timemodified", "type", "typename", "typenameshort", "userid", "usermodified"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ToolDataprivacyGetDataRequestResponseResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of dpouser
        if self.dpouser:
            _dict['dpouser'] = self.dpouser.to_dict()
        # override the default output from pydantic by calling `to_dict()` of foruser
        if self.foruser:
            _dict['foruser'] = self.foruser.to_dict()
        # override the default output from pydantic by calling `to_dict()` of requestedbyuser
        if self.requestedbyuser:
            _dict['requestedbyuser'] = self.requestedbyuser.to_dict()
        # set to None if dpo (nullable) is None
        # and model_fields_set contains the field
        if self.dpo is None and "dpo" in self.model_fields_set:
            _dict['dpo'] = None

        # set to None if dpocomment (nullable) is None
        # and model_fields_set contains the field
        if self.dpocomment is None and "dpocomment" in self.model_fields_set:
            _dict['dpocomment'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ToolDataprivacyGetDataRequestResponseResult from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ToolDataprivacyGetDataRequestResponseResult" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "allowfiltering": obj.get("allowfiltering") if obj.get("allowfiltering") is not None else False,
            "approvedeny": obj.get("approvedeny") if obj.get("approvedeny") is not None else False,
            "canmarkcomplete": obj.get("canmarkcomplete") if obj.get("canmarkcomplete") is not None else False,
            "canreview": obj.get("canreview") if obj.get("canreview") is not None else False,
            "comments": obj.get("comments") if obj.get("comments") is not None else '',
            "commentsformat": obj.get("commentsformat") if obj.get("commentsformat") is not None else 2,
            "creationmethod": obj.get("creationmethod") if obj.get("creationmethod") is not None else 0,
            "downloadlink": obj.get("downloadlink") if obj.get("downloadlink") is not None else '',
            "dpo": obj.get("dpo") if obj.get("dpo") is not None else 0,
            "dpocomment": obj.get("dpocomment") if obj.get("dpocomment") is not None else '',
            "dpocommentformat": obj.get("dpocommentformat") if obj.get("dpocommentformat") is not None else 2,
            "dpouser": CoreCompetencyCreatePlanResponseReviewer.from_dict(obj["dpouser"]) if obj.get("dpouser") is not None else None,
            "foruser": CoreCompetencyCreatePlanResponseReviewer.from_dict(obj["foruser"]) if obj.get("foruser") is not None else None,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "messagehtml": obj.get("messagehtml") if obj.get("messagehtml") is not None else '',
            "requestedby": obj.get("requestedby") if obj.get("requestedby") is not None else 0,
            "requestedbyuser": CoreCompetencyCreatePlanResponseReviewer.from_dict(obj["requestedbyuser"]) if obj.get("requestedbyuser") is not None else None,
            "status": obj.get("status") if obj.get("status") is not None else 0,
            "statuslabel": obj.get("statuslabel") if obj.get("statuslabel") is not None else '',
            "statuslabelclass": obj.get("statuslabelclass") if obj.get("statuslabelclass") is not None else '',
            "systemapproved": obj.get("systemapproved") if obj.get("systemapproved") is not None else False,
            "timecreated": obj.get("timecreated") if obj.get("timecreated") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "type": obj.get("type") if obj.get("type") is not None else 0,
            "typename": obj.get("typename") if obj.get("typename") is not None else '',
            "typenameshort": obj.get("typenameshort") if obj.get("typenameshort") is not None else '',
            "userid": obj.get("userid") if obj.get("userid") is not None else 0,
            "usermodified": obj.get("usermodified") if obj.get("usermodified") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.block_starredcourses_get_starred_courses_response_inner import BlockStarredcoursesGetStarredCoursesResponseInner
from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_action import CoreCalendarGetActionEventsByCourseResponseEventsInnerAction
from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_category import CoreCalendarGetActionEventsByCourseResponseEventsInnerCategory
from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_icon import CoreCalendarGetActionEventsByCourseResponseEventsInnerIcon
from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_subscription import CoreCalendarGetActionEventsByCourseResponseEventsInnerSubscription
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreCalendarGetActionEventsByCourseResponseEventsInner(BaseModel):
    """
    CoreCalendarGetActionEventsByCourseResponseEventsInner
    """ # noqa: E501
    action: Optional[CoreCalendarGetActionEventsByCourseResponseEventsInnerAction] = None
    activityname: Optional[StrictStr] = Field(default=None, description="activityname")
    activitystr: Optional[StrictStr] = Field(default=None, description="activitystr")
    branded: Optional[StrictBool] = Field(default=False, description="branded")
    candelete: StrictBool = Field(description="candelete")
    canedit: StrictBool = Field(description="canedit")
    category: Optional[CoreCalendarGetActionEventsByCourseResponseEventsInnerCategory] = None
    categoryid: Optional[StrictInt] = Field(default=None, description="categoryid")
    component: Optional[StrictStr] = Field(default=None, description="component")
    course: Optional[BlockStarredcoursesGetStarredCoursesResponseInner] = None
    deleteurl: StrictStr = Field(description="deleteurl")
    description: Optional[StrictStr] = Field(default=None, description="description")
    descriptionformat: Optional[StrictInt] = Field(default=1, description="description format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    editurl: StrictStr = Field(description="editurl")
    eventcount: Optional[StrictInt] = Field(default=None, description="eventcount")
    eventtype: StrictStr = Field(description="eventtype")
    formattedlocation: StrictStr = Field(description="formattedlocation")
    formattedtime: StrictStr = Field(description="formattedtime")
    groupid: Optional[StrictInt] = Field(default=None, description="groupid")
    groupname: Optional[StrictStr] = Field(default=None, description="groupname")
    icon: CoreCalendarGetActionEventsByCourseResponseEventsInnerIcon
    id: StrictInt = Field(description="id")
    instance: Optional[StrictInt] = Field(default=None, description="instance")
    isactionevent: StrictBool = Field(description="isactionevent")
    iscategoryevent: StrictBool = Field(description="iscategoryevent")
    iscourseevent: StrictBool = Field(description="iscourseevent")
    location: Optional[StrictStr] = Field(default=None, description="location")
    modulename: Optional[StrictStr] = Field(default=None, description="modulename")
    name: StrictStr = Field(description="name")
    normalisedeventtype: StrictStr = Field(description="normalisedeventtype")
    normalisedeventtypetext: StrictStr = Field(description="normalisedeventtypetext")
    overdue: Optional[StrictBool] = Field(default=False, description="overdue")
    purpose: StrictStr = Field(description="purpose")
    repeatid: Optional[StrictInt] = Field(default=None, description="repeatid")
    subscription: Optional[CoreCalendarGetActionEventsByCourseResponseEventsInnerSubscription] = None
    timeduration: StrictInt = Field(description="timeduration")
    timemodified: StrictInt = Field(description="timemodified")
    timesort: StrictInt = Field(description="timesort")
    timestart: StrictInt = Field(description="timestart")
    timeusermidnight: StrictInt = Field(description="timeusermidnight")
    url: StrictStr = Field(description="url")
    userid: Optional[StrictInt] = Field(default=None, description="userid")
    viewurl: StrictStr = Field(description="viewurl")
    visible: StrictInt = Field(description="visible")
    __properties: ClassVar[List[str]] = ["action", "activityname", "activitystr", "branded", "candelete", "canedit", "category", "categoryid", "component", "course", "deleteurl", "description", "descriptionformat", "editurl", "eventcount", "eventtype", "formattedlocation", "formattedtime", "groupid", "groupname", "icon", "id", "instance", "isactionevent", "iscategoryevent", "iscourseevent", "location", "modulename", "name", "normalisedeventtype", "normalisedeventtypetext", "overdue", "purpose", "repeatid", "subscription", "timeduration", "timemodified", "timesort", "timestart", "timeusermidnight", "url", "userid", "viewurl", "visible"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCalendarGetActionEventsByCourseResponseEventsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of action
        if self.action:
            _dict['action'] = self.action.to_dict()
        # override the default output from pydantic by calling `to_dict()` of category
        if self.category:
            _dict['category'] = self.category.to_dict()
        # override the default output from pydantic by calling `to_dict()` of course
        if self.course:
            _dict['course'] = self.course.to_dict()
        # override the default output from pydantic by calling `to_dict()` of icon
        if self.icon:
            _dict['icon'] = self.icon.to_dict()
        # override the default output from pydantic by calling `to_dict()` of subscription
        if self.subscription:
            _dict['subscription'] = self.subscription.to_dict()
        # set to None if activityname (nullable) is None
        # and model_fields_set contains the field
        if self.activityname is None and "activityname" in self.model_fields_set:
            _dict['activityname'] = None

        # set to None if activitystr (nullable) is None
        # and model_fields_set contains the field
        if self.activitystr is None and "activitystr" in self.model_fields_set:
            _dict['activitystr'] = None

        # set to None if categoryid (nullable) is None
        # and model_fields_set contains the field
        if self.categoryid is None and "categoryid" in self.model_fields_set:
            _dict['categoryid'] = None

        # set to None if component (nullable) is None
        # and model_fields_set contains the field
        if self.component is None and "component" in self.model_fields_set:
            _dict['component'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if descriptionformat (nullable) is None
        # and model_fields_set contains the field
        if self.descriptionformat is None and "descriptionformat" in self.model_fields_set:
            _dict['descriptionformat'] = None

        # set to None if eventcount (nullable) is None
        # and model_fields_set contains the field
        if self.eventcount is None and "eventcount" in self.model_fields_set:
            _dict['eventcount'] = None

        # set to None if groupid (nullable) is None
        # and model_fields_set contains the field
        if self.groupid is None and "groupid" in self.model_fields_set:
            _dict['groupid'] = None

        # set to None if groupname (nullable) is None
        # and model_fields_set contains the field
        if self.groupname is None and "groupname" in self.model_fields_set:
            _dict['groupname'] = None

        # set to None if instance (nullable) is None
        # and model_fields_set contains the field
        if self.instance is None and "instance" in self.model_fields_set:
            _dict['instance'] = None

        # set to None if location (nullable) is None
        # and model_fields_set contains the field
        if self.location is None and "location" in self.model_fields_set:
            _dict['location'] = None

        # set to None if modulename (nullable) is None
        # and model_fields_set contains the field
        if self.modulename is None and "modulename" in self.model_fields_set:
            _dict['modulename'] = None

        # set to None if overdue (nullable) is None
        # and model_fields_set contains the field
        if self.overdue is None and "overdue" in self.model_fields_set:
            _dict['overdue'] = None

        # set to None if repeatid (nullable) is None
        # and model_fields_set contains the field
        if self.repeatid is None and "repeatid" in self.model_fields_set:
            _dict['repeatid'] = None

        # set to None if userid (nullable) is None
        # and model_fields_set contains the field
        if self.userid is None and "userid" in self.model_fields_set:
            _dict['userid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCalendarGetActionEventsByCourseResponseEventsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCalendarGetActionEventsByCourseResponseEventsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "action": CoreCalendarGetActionEventsByCourseResponseEventsInnerAction.from_dict(obj["action"]) if obj.get("action") is not None else None,
            "activityname": obj.get("activityname"),
            "activitystr": obj.get("activitystr"),
            "branded": obj.get("branded") if obj.get("branded") is not None else False,
            "candelete": obj.get("candelete") if obj.get("candelete") is not None else False,
            "canedit": obj.get("canedit") if obj.get("canedit") is not None else False,
            "category": CoreCalendarGetActionEventsByCourseResponseEventsInnerCategory.from_dict(obj["category"]) if obj.get("category") is not None else None,
            "categoryid": obj.get("categoryid"),
            "component": obj.get("component"),
            "course": BlockStarredcoursesGetStarredCoursesResponseInner.from_dict(obj["course"]) if obj.get("course") is not None else None,
            "deleteurl": obj.get("deleteurl") if obj.get("deleteurl") is not None else '',
            "description": obj.get("description"),
            "descriptionformat": obj.get("descriptionformat") if obj.get("descriptionformat") is not None else 1,
            "editurl": obj.get("editurl") if obj.get("editurl") is not None else '',
            "eventcount": obj.get("eventcount"),
            "eventtype": obj.get("eventtype") if obj.get("eventtype") is not None else '',
            "formattedlocation": obj.get("formattedlocation") if obj.get("formattedlocation") is not None else '',
            "formattedtime": obj.get("formattedtime") if obj.get("formattedtime") is not None else '',
            "groupid": obj.get("groupid"),
            "groupname": obj.get("groupname"),
            "icon": CoreCalendarGetActionEventsByCourseResponseEventsInnerIcon.from_dict(obj["icon"]) if obj.get("icon") is not None else None,
            "id": obj.get("id") if obj.get("id") is not None else 0,
            "instance": obj.get("instance"),
            "isactionevent": obj.get("isactionevent") if obj.get("isactionevent") is not None else False,
            "iscategoryevent": obj.get("iscategoryevent") if obj.get("iscategoryevent") is not None else False,
            "iscourseevent": obj.get("iscourseevent") if obj.get("iscourseevent") is not None else False,
            "location": obj.get("location"),
            "modulename": obj.get("modulename"),
            "name": obj.get("name") if obj.get("name") is not None else '',
            "normalisedeventtype": obj.get("normalisedeventtype") if obj.get("normalisedeventtype") is not None else '',
            "normalisedeventtypetext": obj.get("normalisedeventtypetext") if obj.get("normalisedeventtypetext") is not None else '',
            "overdue": obj.get("overdue") if obj.get("overdue") is not None else False,
            "purpose": obj.get("purpose") if obj.get("purpose") is not None else '',
            "repeatid": obj.get("repeatid"),
            "subscription": CoreCalendarGetActionEventsByCourseResponseEventsInnerSubscription.from_dict(obj["subscription"]) if obj.get("subscription") is not None else None,
            "timeduration": obj.get("timeduration") if obj.get("timeduration") is not None else 0,
            "timemodified": obj.get("timemodified") if obj.get("timemodified") is not None else 0,
            "timesort": obj.get("timesort") if obj.get("timesort") is not None else 0,
            "timestart": obj.get("timestart") if obj.get("timestart") is not None else 0,
            "timeusermidnight": obj.get("timeusermidnight") if obj.get("timeusermidnight") is not None else 0,
            "url": obj.get("url") if obj.get("url") is not None else '',
            "userid": obj.get("userid"),
            "viewurl": obj.get("viewurl") if obj.get("viewurl") is not None else '',
            "visible": obj.get("visible") if obj.get("visible") is not None else 0
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from poodle_async_full.models.auth_email_get_signup_settings_response_warnings_inner import AuthEmailGetSignupSettingsResponseWarningsInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModWorkshopGetWorkshopAccessInformationResponse(BaseModel):
    """
    ModWorkshopGetWorkshopAccessInformationResponse
    """ # noqa: E501
    assessingallowed: Optional[StrictBool] = Field(description="Is the user allowed to create/edit his assessments?")
    assessingexamplesallowed: Optional[StrictBool] = Field(description="Are reviewers allowed to create/edit their assessments of the example submissions?.")
    canaddinstance: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:addinstance allowed.")
    canallocate: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:allocate allowed.")
    candeletesubmissions: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:deletesubmissions allowed.")
    caneditdimensions: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:editdimensions allowed.")
    canexportsubmissions: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:exportsubmissions allowed.")
    canignoredeadlines: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:ignoredeadlines allowed.")
    canmanageexamples: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:manageexamples allowed.")
    canoverridegrades: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:overridegrades allowed.")
    canpeerassess: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:peerassess allowed.")
    canpublishsubmissions: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:publishsubmissions allowed.")
    cansubmit: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:submit allowed.")
    canswitchphase: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:switchphase allowed.")
    canview: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:view allowed.")
    canviewallassessments: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:viewallassessments allowed.")
    canviewallsubmissions: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:viewallsubmissions allowed.")
    canviewauthornames: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:viewauthornames allowed.")
    canviewauthorpublished: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:viewauthorpublished allowed.")
    canviewpublishedsubmissions: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:viewpublishedsubmissions allowed.")
    canviewreviewernames: Optional[StrictBool] = Field(description="Whether the user has the capability mod/workshop:viewreviewernames allowed.")
    creatingsubmissionallowed: Optional[StrictBool] = Field(description="Is the given user allowed to create their submission?")
    examplesassessedbeforeassessment: Optional[StrictBool] = Field(description="Whether the given user has assessed all his required examples before assessment                 (always true if there are not examples to assessor not configured to check before assessment).")
    examplesassessedbeforesubmission: Optional[StrictBool] = Field(description="Whether the given user has assessed all his required examples before submission                 (always true if there are not examples to assess or not configured to check before submission).")
    modifyingsubmissionallowed: Optional[StrictBool] = Field(description="Is the user allowed to modify his existing submission?")
    warnings: Optional[List[AuthEmailGetSignupSettingsResponseWarningsInner]] = Field(default=None, description="list of warnings")
    __properties: ClassVar[List[str]] = ["assessingallowed", "assessingexamplesallowed", "canaddinstance", "canallocate", "candeletesubmissions", "caneditdimensions", "canexportsubmissions", "canignoredeadlines", "canmanageexamples", "canoverridegrades", "canpeerassess", "canpublishsubmissions", "cansubmit", "canswitchphase", "canview", "canviewallassessments", "canviewallsubmissions", "canviewauthornames", "canviewauthorpublished", "canviewpublishedsubmissions", "canviewreviewernames", "creatingsubmissionallowed", "examplesassessedbeforeassessment", "examplesassessedbeforesubmission", "modifyingsubmissionallowed", "warnings"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModWorkshopGetWorkshopAccessInformationResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in warnings (list)
        _items = []
        if self.warnings:
            for _item_warnings in self.warnings:
                if _item_warnings:
                    _items.append(_item_warnings.to_dict())
            _dict['warnings'] = _items
        # set to None if assessingallowed (nullable) is None
        # and model_fields_set contains the field
        if self.assessingallowed is None and "assessingallowed" in self.model_fields_set:
            _dict['assessingallowed'] = None

        # set to None if assessingexamplesallowed (nullable) is None
        # and model_fields_set contains the field
        if self.assessingexamplesallowed is None and "assessingexamplesallowed" in self.model_fields_set:
            _dict['assessingexamplesallowed'] = None

        # set to None if canaddinstance (nullable) is None
        # and model_fields_set contains the field
        if self.canaddinstance is None and "canaddinstance" in self.model_fields_set:
            _dict['canaddinstance'] = None

        # set to None if canallocate (nullable) is None
        # and model_fields_set contains the field
        if self.canallocate is None and "canallocate" in self.model_fields_set:
            _dict['canallocate'] = None

        # set to None if candeletesubmissions (nullable) is None
        # and model_fields_set contains the field
        if self.candeletesubmissions is None and "candeletesubmissions" in self.model_fields_set:
            _dict['candeletesubmissions'] = None

        # set to None if caneditdimensions (nullable) is None
        # and model_fields_set contains the field
        if self.caneditdimensions is None and "caneditdimensions" in self.model_fields_set:
            _dict['caneditdimensions'] = None

        # set to None if canexportsubmissions (nullable) is None
        # and model_fields_set contains the field
        if self.canexportsubmissions is None and "canexportsubmissions" in self.model_fields_set:
            _dict['canexportsubmissions'] = None

        # set to None if canignoredeadlines (nullable) is None
        # and model_fields_set contains the field
        if self.canignoredeadlines is None and "canignoredeadlines" in self.model_fields_set:
            _dict['canignoredeadlines'] = None

        # set to None if canmanageexamples (nullable) is None
        # and model_fields_set contains the field
        if self.canmanageexamples is None and "canmanageexamples" in self.model_fields_set:
            _dict['canmanageexamples'] = None

        # set to None if canoverridegrades (nullable) is None
        # and model_fields_set contains the field
        if self.canoverridegrades is None and "canoverridegrades" in self.model_fields_set:
            _dict['canoverridegrades'] = None

        # set to None if canpeerassess (nullable) is None
        # and model_fields_set contains the field
        if self.canpeerassess is None and "canpeerassess" in self.model_fields_set:
            _dict['canpeerassess'] = None

        # set to None if canpublishsubmissions (nullable) is None
        # and model_fields_set contains the field
        if self.canpublishsubmissions is None and "canpublishsubmissions" in self.model_fields_set:
            _dict['canpublishsubmissions'] = None

        # set to None if cansubmit (nullable) is None
        # and model_fields_set contains the field
        if self.cansubmit is None and "cansubmit" in self.model_fields_set:
            _dict['cansubmit'] = None

        # set to None if canswitchphase (nullable) is None
        # and model_fields_set contains the field
        if self.canswitchphase is None and "canswitchphase" in self.model_fields_set:
            _dict['canswitchphase'] = None

        # set to None if canview (nullable) is None
        # and model_fields_set contains the field
        if self.canview is None and "canview" in self.model_fields_set:
            _dict['canview'] = None

        # set to None if canviewallassessments (nullable) is None
        # and model_fields_set contains the field
        if self.canviewallassessments is None and "canviewallassessments" in self.model_fields_set:
            _dict['canviewallassessments'] = None

        # set to None if canviewallsubmissions (nullable) is None
        # and model_fields_set contains the field
        if self.canviewallsubmissions is None and "canviewallsubmissions" in self.model_fields_set:
            _dict['canviewallsubmissions'] = None

        # set to None if canviewauthornames (nullable) is None
        # and model_fields_set contains the field
        if self.canviewauthornames is None and "canviewauthornames" in self.model_fields_set:
            _dict['canviewauthornames'] = None

        # set to None if canviewauthorpublished (nullable) is None
        # and model_fields_set contains the field
        if self.canviewauthorpublished is None and "canviewauthorpublished" in self.model_fields_set:
            _dict['canviewauthorpublished'] = None

        # set to None if canviewpublishedsubmissions (nullable) is None
        # and model_fields_set contains the field
        if self.canviewpublishedsubmissions is None and "canviewpublishedsubmissions" in self.model_fields_set:
            _dict['canviewpublishedsubmissions'] = None

        # set to None if canviewreviewernames (nullable) is None
        # and model_fields_set contains the field
        if self.canviewreviewernames is None and "canviewreviewernames" in self.model_fields_set:
            _dict['canviewreviewernames'] = None

        # set to None if creatingsubmissionallowed (nullable) is None
        # and model_fields_set contains the field
        if self.creatingsubmissionallowed is None and "creatingsubmissionallowed" in self.model_fields_set:
            _dict['creatingsubmissionallowed'] = None

        # set to None if examplesassessedbeforeassessment (nullable) is None
        # and model_fields_set contains the field
        if self.examplesassessedbeforeassessment is None and "examplesassessedbeforeassessment" in self.model_fields_set:
            _dict['examplesassessedbeforeassessment'] = None

        # set to None if examplesassessedbeforesubmission (nullable) is None
        # and model_fields_set contains the field
        if self.examplesassessedbeforesubmission is None and "examplesassessedbeforesubmission" in self.model_fields_set:
            _dict['examplesassessedbeforesubmission'] = None

        # set to None if modifyingsubmissionallowed (nullable) is None
        # and model_fields_set contains the field
        if self.modifyingsubmissionallowed is None and "modifyingsubmissionallowed" in self.model_fields_set:
            _dict['modifyingsubmissionallowed'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModWorkshopGetWorkshopAccessInformationResponse from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModWorkshopGetWorkshopAccessInformationResponse" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "assessingallowed": obj.get("assessingallowed"),
            "assessingexamplesallowed": obj.get("assessingexamplesallowed"),
            "canaddinstance": obj.get("canaddinstance"),
            "canallocate": obj.get("canallocate"),
            "candeletesubmissions": obj.get("candeletesubmissions"),
            "caneditdimensions": obj.get("caneditdimensions"),
            "canexportsubmissions": obj.get("canexportsubmissions"),
            "canignoredeadlines": obj.get("canignoredeadlines"),
            "canmanageexamples": obj.get("canmanageexamples"),
            "canoverridegrades": obj.get("canoverridegrades"),
            "canpeerassess": obj.get("canpeerassess"),
            "canpublishsubmissions": obj.get("canpublishsubmissions"),
            "cansubmit": obj.get("cansubmit"),
            "canswitchphase": obj.get("canswitchphase"),
            "canview": obj.get("canview"),
            "canviewallassessments": obj.get("canviewallassessments"),
            "canviewallsubmissions": obj.get("canviewallsubmissions"),
            "canviewauthornames": obj.get("canviewauthornames"),
            "canviewauthorpublished": obj.get("canviewauthorpublished"),
            "canviewpublishedsubmissions": obj.get("canviewpublishedsubmissions"),
            "canviewreviewernames": obj.get("canviewreviewernames"),
            "creatingsubmissionallowed": obj.get("creatingsubmissionallowed"),
            "examplesassessedbeforeassessment": obj.get("examplesassessedbeforeassessment"),
            "examplesassessedbeforesubmission": obj.get("examplesassessedbeforesubmission"),
            "modifyingsubmissionallowed": obj.get("modifyingsubmissionallowed"),
            "warnings": [AuthEmailGetSignupSettingsResponseWarningsInner.from_dict(_item) for _item in obj["warnings"]] if obj.get("warnings") is not None else None
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from poodle_async_full.models.mod_quiz_get_attempt_data_response_questions_inner_responsefileareas_inner import ModQuizGetAttemptDataResponseQuestionsInnerResponsefileareasInner
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModQuizGetAttemptDataResponseQuestionsInner(BaseModel):
    """
    The question data. Some fields may not be returned depending on the quiz display settings.
    """ # noqa: E501
    blockedbyprevious: Optional[StrictBool] = Field(default=None, description="whether the question is blocked by the previous question")
    flagged: Optional[StrictBool] = Field(description="whether the question is flagged or not")
    hasautosavedstep: Optional[StrictBool] = Field(default=None, description="whether this question attempt has autosaved data")
    html: Optional[StrictStr] = Field(description="the question rendered")
    lastactiontime: Optional[StrictInt] = Field(default=None, description="the timestamp of the most recent step in this question attempt")
    mark: Optional[StrictStr] = Field(default=None, description="the mark awarded.                     It will be returned only if the user is allowed to see it.")
    maxmark: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="the maximum mark possible for this question attempt.                     It will be returned only if the user is allowed to see it.")
    number: Optional[StrictInt] = Field(default=None, description="DO NOT USE. Use questionnumber. Only retained for backwards compatibility.")
    page: Optional[StrictInt] = Field(description="page of the quiz this question appears on")
    questionnumber: Optional[StrictStr] = Field(description="The question number to display for this question, e.g. \"7\", \"i\" or \"Custom-B)\".")
    responsefileareas: Optional[List[ModQuizGetAttemptDataResponseQuestionsInnerResponsefileareasInner]] = Field(default=None, description="Response file areas including files")
    sequencecheck: Optional[StrictInt] = Field(default=None, description="the number of real steps in this attempt")
    settings: Optional[StrictStr] = Field(default=None, description="Question settings (JSON encoded).")
    slot: Optional[StrictInt] = Field(description="slot number")
    state: Optional[StrictStr] = Field(default=None, description="the state where the question is in terms of correctness.                     It will not be returned if the user cannot see it due to the quiz display correctness settings.")
    stateclass: Optional[StrictStr] = Field(default=None, description="A machine-readable class name for the state that this question attempt is in, as returned by question_usage_by_activity::get_question_state_class().                     Always returned.")
    status: Optional[StrictStr] = Field(default=None, description="Human readable state of the question.")
    type: Optional[StrictStr] = Field(description="question type, i.e: multichoice")
    __properties: ClassVar[List[str]] = ["blockedbyprevious", "flagged", "hasautosavedstep", "html", "lastactiontime", "mark", "maxmark", "number", "page", "questionnumber", "responsefileareas", "sequencecheck", "settings", "slot", "state", "stateclass", "status", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModQuizGetAttemptDataResponseQuestionsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in responsefileareas (list)
        _items = []
        if self.responsefileareas:
            for _item_responsefileareas in self.responsefileareas:
                if _item_responsefileareas:
                    _items.append(_item_responsefileareas.to_dict())
            _dict['responsefileareas'] = _items
        # set to None if blockedbyprevious (nullable) is None
        # and model_fields_set contains the field
        if self.blockedbyprevious is None and "blockedbyprevious" in self.model_fields_set:
            _dict['blockedbyprevious'] = None

        # set to None if flagged (nullable) is None
        # and model_fields_set contains the field
        if self.flagged is None and "flagged" in self.model_fields_set:
            _dict['flagged'] = None

        # set to None if hasautosavedstep (nullable) is None
        # and model_fields_set contains the field
        if self.hasautosavedstep is None and "hasautosavedstep" in self.model_fields_set:
            _dict['hasautosavedstep'] = None

        # set to None if html (nullable) is None
        # and model_fields_set contains the field
        if self.html is None and "html" in self.model_fields_set:
            _dict['html'] = None

        # set to None if lastactiontime (nullable) is None
        # and model_fields_set contains the field
        if self.lastactiontime is None and "lastactiontime" in self.model_fields_set:
            _dict['lastactiontime'] = None

        # set to None if mark (nullable) is None
        # and model_fields_set contains the field
        if self.mark is None and "mark" in self.model_fields_set:
            _dict['mark'] = None

        # set to None if maxmark (nullable) is None
        # and model_fields_set contains the field
        if self.maxmark is None and "maxmark" in self.model_fields_set:
            _dict['maxmark'] = None

        # set to None if number (nullable) is None
        # and model_fields_set contains the field
        if self.number is None and "number" in self.model_fields_set:
            _dict['number'] = None

        # set to None if page (nullable) is None
        # and model_fields_set contains the field
        if self.page is None and "page" in self.model_fields_set:
            _dict['page'] = None

        # set to None if questionnumber (nullable) is None
        # and model_fields_set contains the field
        if self.questionnumber is None and "questionnumber" in self.model_fields_set:
            _dict['questionnumber'] = None

        # set to None if sequencecheck (nullable) is None
        # and model_fields_set contains the field
        if self.sequencecheck is None and "sequencecheck" in self.model_fields_set:
            _dict['sequencecheck'] = None

        # set to None if settings (nullable) is None
        # and model_fields_set contains the field
        if self.settings is None and "settings" in self.model_fields_set:
            _dict['settings'] = None

        # set to None if slot (nullable) is None
        # and model_fields_set contains the field
        if self.slot is None and "slot" in self.model_fields_set:
            _dict['slot'] = None

        # set to None if state (nullable) is None
        # and model_fields_set contains the field
        if self.state is None and "state" in self.model_fields_set:
            _dict['state'] = None

        # set to None if stateclass (nullable) is None
        # and model_fields_set contains the field
        if self.stateclass is None and "stateclass" in self.model_fields_set:
            _dict['stateclass'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if type (nullable) is None
        # and model_fields_set contains the field
        if self.type is None and "type" in self.model_fields_set:
            _dict['type'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModQuizGetAttemptDataResponseQuestionsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModQuizGetAttemptDataResponseQuestionsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "blockedbyprevious": obj.get("blockedbyprevious"),
            "flagged": obj.get("flagged"),
            "hasautosavedstep": obj.get("hasautosavedstep"),
            "html": obj.get("html"),
            "lastactiontime": obj.get("lastactiontime"),
            "mark": obj.get("mark"),
            "maxmark": obj.get("maxmark"),
            "number": obj.get("number"),
            "page": obj.get("page"),
            "questionnumber": obj.get("questionnumber"),
            "responsefileareas": [ModQuizGetAttemptDataResponseQuestionsInnerResponsefileareasInner.from_dict(_item) for _item in obj["responsefileareas"]] if obj.get("responsefileareas") is not None else None,
            "sequencecheck": obj.get("sequencecheck"),
            "settings": obj.get("settings"),
            "slot": obj.get("slot"),
            "state": obj.get("state"),
            "stateclass": obj.get("stateclass"),
            "status": obj.get("status"),
            "type": obj.get("type")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class CoreMessageGetMessagesResponseMessagesInner(BaseModel):
    """
    message
    """ # noqa: E501
    component: Optional[StrictStr] = Field(default=None, description="The component that generated the notification")
    contexturl: Optional[StrictStr] = Field(description="Context URL")
    contexturlname: Optional[StrictStr] = Field(description="Context URL link name")
    customdata: Optional[StrictStr] = Field(default=None, description="Custom data to be passed to the message processor.                                 The data here is serialised using json_encode().")
    eventtype: Optional[StrictStr] = Field(default=None, description="The type of notification")
    fullmessage: Optional[StrictStr] = Field(description="The message")
    fullmessageformat: Optional[StrictInt] = Field(description="fullmessage format (1 = HTML, 0 = MOODLE, 2 = PLAIN, or 4 = MARKDOWN)")
    fullmessagehtml: Optional[StrictStr] = Field(description="The message in html")
    iconurl: Optional[StrictStr] = Field(default=None, description="URL for icon, only for notifications.")
    id: Optional[StrictInt] = Field(description="Message id")
    notification: Optional[StrictInt] = Field(description="Is a notification?")
    smallmessage: Optional[StrictStr] = Field(description="The shorten message")
    subject: Optional[StrictStr] = Field(description="The message subject")
    text: Optional[StrictStr] = Field(description="The message text formated")
    timecreated: Optional[StrictInt] = Field(description="Time created")
    timeread: Optional[StrictInt] = Field(description="Time read")
    userfromfullname: Optional[StrictStr] = Field(description="User from full name")
    useridfrom: Optional[StrictInt] = Field(description="User from id")
    useridto: Optional[StrictInt] = Field(description="User to id")
    usertofullname: Optional[StrictStr] = Field(description="User to full name")
    __properties: ClassVar[List[str]] = ["component", "contexturl", "contexturlname", "customdata", "eventtype", "fullmessage", "fullmessageformat", "fullmessagehtml", "iconurl", "id", "notification", "smallmessage", "subject", "text", "timecreated", "timeread", "userfromfullname", "useridfrom", "useridto", "usertofullname"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreMessageGetMessagesResponseMessagesInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if component (nullable) is None
        # and model_fields_set contains the field
        if self.component is None and "component" in self.model_fields_set:
            _dict['component'] = None

        # set to None if contexturl (nullable) is None
        # and model_fields_set contains the field
        if self.contexturl is None and "contexturl" in self.model_fields_set:
            _dict['contexturl'] = None

        # set to None if contexturlname (nullable) is None
        # and model_fields_set contains the field
        if self.contexturlname is None and "contexturlname" in self.model_fields_set:
            _dict['contexturlname'] = None

        # set to None if customdata (nullable) is None
        # and model_fields_set contains the field
        if self.customdata is None and "customdata" in self.model_fields_set:
            _dict['customdata'] = None

        # set to None if eventtype (nullable) is None
        # and model_fields_set contains the field
        if self.eventtype is None and "eventtype" in self.model_fields_set:
            _dict['eventtype'] = None

        # set to None if fullmessage (nullable) is None
        # and model_fields_set contains the field
        if self.fullmessage is None and "fullmessage" in self.model_fields_set:
            _dict['fullmessage'] = None

        # set to None if fullmessageformat (nullable) is None
        # and model_fields_set contains the field
        if self.fullmessageformat is None and "fullmessageformat" in self.model_fields_set:
            _dict['fullmessageformat'] = None

        # set to None if fullmessagehtml (nullable) is None
        # and model_fields_set contains the field
        if self.fullmessagehtml is None and "fullmessagehtml" in self.model_fields_set:
            _dict['fullmessagehtml'] = None

        # set to None if iconurl (nullable) is None
        # and model_fields_set contains the field
        if self.iconurl is None and "iconurl" in self.model_fields_set:
            _dict['iconurl'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if notification (nullable) is None
        # and model_fields_set contains the field
        if self.notification is None and "notification" in self.model_fields_set:
            _dict['notification'] = None

        # set to None if smallmessage (nullable) is None
        # and model_fields_set contains the field
        if self.smallmessage is None and "smallmessage" in self.model_fields_set:
            _dict['smallmessage'] = None

        # set to None if subject (nullable) is None
        # and model_fields_set contains the field
        if self.subject is None and "subject" in self.model_fields_set:
            _dict['subject'] = None

        # set to None if text (nullable) is None
        # and model_fields_set contains the field
        if self.text is None and "text" in self.model_fields_set:
            _dict['text'] = None

        # set to None if timecreated (nullable) is None
        # and model_fields_set contains the field
        if self.timecreated is None and "timecreated" in self.model_fields_set:
            _dict['timecreated'] = None

        # set to None if timeread (nullable) is None
        # and model_fields_set contains the field
        if self.timeread is None and "timeread" in self.model_fields_set:
            _dict['timeread'] = None

        # set to None if userfromfullname (nullable) is None
        # and model_fields_set contains the field
        if self.userfromfullname is None and "userfromfullname" in self.model_fields_set:
            _dict['userfromfullname'] = None

        # set to None if useridfrom (nullable) is None
        # and model_fields_set contains the field
        if self.useridfrom is None and "useridfrom" in self.model_fields_set:
            _dict['useridfrom'] = None

        # set to None if useridto (nullable) is None
        # and model_fields_set contains the field
        if self.useridto is None and "useridto" in self.model_fields_set:
            _dict['useridto'] = None

        # set to None if usertofullname (nullable) is None
        # and model_fields_set contains the field
        if self.usertofullname is None and "usertofullname" in self.model_fields_set:
            _dict['usertofullname'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreMessageGetMessagesResponseMessagesInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreMessageGetMessagesResponseMessagesInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "component": obj.get("component"),
            "contexturl": obj.get("contexturl"),
            "contexturlname": obj.get("contexturlname"),
            "customdata": obj.get("customdata"),
            "eventtype": obj.get("eventtype"),
            "fullmessage": obj.get("fullmessage"),
            "fullmessageformat": obj.get("fullmessageformat"),
            "fullmessagehtml": obj.get("fullmessagehtml"),
            "iconurl": obj.get("iconurl"),
            "id": obj.get("id"),
            "notification": obj.get("notification"),
            "smallmessage": obj.get("smallmessage"),
            "subject": obj.get("subject"),
            "text": obj.get("text"),
            "timecreated": obj.get("timecreated"),
            "timeread": obj.get("timeread"),
            "userfromfullname": obj.get("userfromfullname"),
            "useridfrom": obj.get("useridfrom"),
            "useridto": obj.get("useridto"),
            "usertofullname": obj.get("usertofullname")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj





# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_full.configuration import settings

class ModForumAddDiscussionPostResponsePostUrls(BaseModel):
    """
    ModForumAddDiscussionPostResponsePostUrls
    """ # noqa: E501
    delete: Optional[StrictStr] = Field(default=None, description="The URL used to delete the post")
    discuss: Optional[StrictStr] = Field(default=None, description="discuss")
    edit: Optional[StrictStr] = Field(default=None, description="The URL used to edit the post")
    export: Optional[StrictStr] = Field(default=None, description="The URL used to export the post")
    markasread: Optional[StrictStr] = Field(default=None, description="The URL used to mark the post as read")
    markasunread: Optional[StrictStr] = Field(default=None, description="The URL used to mark the post as unread")
    reply: Optional[StrictStr] = Field(default=None, description="The URL used to reply to the post")
    split: Optional[StrictStr] = Field(default=None, description="The URL used to split the discussion with the selected post being the first post in the new discussion")
    view: Optional[StrictStr] = Field(default=None, description="The URL used to view the post")
    viewisolated: Optional[StrictStr] = Field(default=None, description="The URL used to view the post in isolation")
    viewparent: Optional[StrictStr] = Field(default=None, description="The URL used to view the parent of the post")
    __properties: ClassVar[List[str]] = ["delete", "discuss", "edit", "export", "markasread", "markasunread", "reply", "split", "view", "viewisolated", "viewparent"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModForumAddDiscussionPostResponsePostUrls from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if delete (nullable) is None
        # and model_fields_set contains the field
        if self.delete is None and "delete" in self.model_fields_set:
            _dict['delete'] = None

        # set to None if discuss (nullable) is None
        # and model_fields_set contains the field
        if self.discuss is None and "discuss" in self.model_fields_set:
            _dict['discuss'] = None

        # set to None if edit (nullable) is None
        # and model_fields_set contains the field
        if self.edit is None and "edit" in self.model_fields_set:
            _dict['edit'] = None

        # set to None if export (nullable) is None
        # and model_fields_set contains the field
        if self.export is None and "export" in self.model_fields_set:
            _dict['export'] = None

        # set to None if markasread (nullable) is None
        # and model_fields_set contains the field
        if self.markasread is None and "markasread" in self.model_fields_set:
            _dict['markasread'] = None

        # set to None if markasunread (nullable) is None
        # and model_fields_set contains the field
        if self.markasunread is None and "markasunread" in self.model_fields_set:
            _dict['markasunread'] = None

        # set to None if reply (nullable) is None
        # and model_fields_set contains the field
        if self.reply is None and "reply" in self.model_fields_set:
            _dict['reply'] = None

        # set to None if split (nullable) is None
        # and model_fields_set contains the field
        if self.split is None and "split" in self.model_fields_set:
            _dict['split'] = None

        # set to None if view (nullable) is None
        # and model_fields_set contains the field
        if self.view is None and "view" in self.model_fields_set:
            _dict['view'] = None

        # set to None if viewisolated (nullable) is None
        # and model_fields_set contains the field
        if self.viewisolated is None and "viewisolated" in self.model_fields_set:
            _dict['viewisolated'] = None

        # set to None if viewparent (nullable) is None
        # and model_fields_set contains the field
        if self.viewparent is None and "viewparent" in self.model_fields_set:
            _dict['viewparent'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModForumAddDiscussionPostResponsePostUrls from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "ModForumAddDiscussionPostResponsePostUrls" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "delete": obj.get("delete"),
            "discuss": obj.get("discuss"),
            "edit": obj.get("edit"),
            "export": obj.get("export"),
            "markasread": obj.get("markasread"),
            "markasunread": obj.get("markasunread"),
            "reply": obj.get("reply"),
            "split": obj.get("split"),
            "view": obj.get("view"),
            "viewisolated": obj.get("viewisolated"),
            "viewparent": obj.get("viewparent")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj


